Safe cuSOLVER wrappers for dense linear algebra and solver operations.
This crate covers cuSOLVER context management, dense matrix routines, eigenvalue helpers, SVD helpers, iterative refinement solver APIs, and parameter objects.
Modules
Macros
Functions
- library_
property - Returns the requested cuSOLVER library property.
See
LibraryPropertyfor supported properties. - version
- Returns the cuSOLVER library version.