Module dense

Module dense 

Functions

cgebrd
Use the matching buffer-size helper to calculate the required workspace size.
cgebrd_buffer_size
cgeqrf
Use the matching buffer-size helper to calculate the required workspace size.
cgeqrf_buffer_size
cgetrf
Use the matching buffer-size helper to calculate the required workspace size.
cgetrf_buffer_size
cgetrs
Solves a linear system of multiple right-hand sides
chetrd
chetrd_buffer_size
cpotrf
Use the matching buffer-size helper to calculate the required workspace size.
cpotrf_batched
The S and D data types are real valued single and double precision, respectively.
cpotrf_buffer_size
cpotri
Use the matching buffer-size helper to calculate the required workspace size.
cpotri_buffer_size
cpotrs
Solves a system of linear equations
csytrf
Use the matching buffer-size helper to calculate the required workspace size.
csytrf_buffer_size
cungbr
cungbr_buffer_size
cungqr
cungqr_buffer_size
cungtr
cungtr_buffer_size
cunmqr
cunmqr_buffer_size
cunmtr
cunmtr_buffer_size
dgebrd
Use the matching buffer-size helper to calculate the required workspace size.
dgebrd_buffer_size
dgeqrf
Use the matching buffer-size helper to calculate the required workspace size.
dgeqrf_buffer_size
dgetrf
Use the matching buffer-size helper to calculate the required workspace size.
dgetrf_buffer_size
dgetrs
Solves a linear system of multiple right-hand sides
dorgbr
Use the matching buffer-size helper to calculate the required workspace size.
dorgbr_buffer_size
dorgqr
Use the matching buffer-size helper to calculate the required workspace size.
dorgqr_buffer_size
dorgtr
Use the matching buffer-size helper to calculate the required workspace size.
dorgtr_buffer_size
dormqr
Use the matching buffer-size helper to calculate the required workspace size.
dormqr_buffer_size
dormtr
Use the matching buffer-size helper to calculate the required workspace size.
dormtr_buffer_size
dpotrf
Use the matching buffer-size helper to calculate the required workspace size.
dpotrf_batched
The S and D data types are real valued single and double precision, respectively.
dpotrf_buffer_size
dpotri
Use the matching buffer-size helper to calculate the required workspace size.
dpotri_buffer_size
dpotrs
Solves a system of linear equations
dpotrs_batched
Solves a sequence of linear systems
dsytrd
Use the matching buffer-size helper to calculate the required workspace size.
dsytrd_buffer_size
dsytrf
Use the matching buffer-size helper to calculate the required workspace size.
dsytrf_buffer_size
sgebrd
Use the matching buffer-size helper to calculate the required workspace size.
sgebrd_buffer_size
sgeqrf
Use the matching buffer-size helper to calculate the required workspace size.
sgeqrf_buffer_size
sgetrf
Use the matching buffer-size helper to calculate the required workspace size.
sgetrf_buffer_size
sgetrs
Solves a linear system of multiple right-hand sides
sorgbr
Use the matching buffer-size helper to calculate the required workspace size.
sorgbr_buffer_size
sorgqr
Use the matching buffer-size helper to calculate the required workspace size.
sorgqr_buffer_size
sorgtr
Use the matching buffer-size helper to calculate the required workspace size.
sorgtr_buffer_size
sormqr
Use the matching buffer-size helper to calculate the required workspace size.
sormqr_buffer_size
sormtr
Use the matching buffer-size helper to calculate the required workspace size.
sormtr_buffer_size
spotrf
Use the matching buffer-size helper to calculate the required workspace size.
spotrf_batched
The S and D data types are real valued single and double precision, respectively.
spotrf_buffer_size
spotri
Use the matching buffer-size helper to calculate the required workspace size.
spotri_buffer_size
spotrs
Solves a system of linear equations
spotrs_batched
Solves a sequence of linear systems
ssytrd
Use the matching buffer-size helper to calculate the required workspace size.
ssytrd_buffer_size
ssytrf
Use the matching buffer-size helper to calculate the required workspace size.
ssytrf_buffer_size
xgeqrf
Use xgeqrf_buffer_size to calculate the sizes needed for pre-allocated workspace.
xgeqrf_buffer_size
xgetrf
Computes the LU factorization of an $m \times n$ matrix
xgetrf_buffer_size
xgetrs
Solves a linear system of multiple right-hand sides
xlarft
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xlarft_buffer_size
xpotrf
Use xpotrf_buffer_size to calculate the sizes needed for pre-allocated workspace.
xpotrf_buffer_size
xpotrs
Solves a system of linear equations.
xsytrs
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xsytrs_buffer_size
xtrtri
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xtrtri_buffer_size
zgebrd
Use the matching buffer-size helper to calculate the required workspace size.
zgebrd_buffer_size
zgeqrf
Use the matching buffer-size helper to calculate the required workspace size.
zgeqrf_buffer_size
zgetrf
Use the matching buffer-size helper to calculate the required workspace size.
zgetrf_buffer_size
zgetrs
Solves a linear system of multiple right-hand sides
zhetrd
zhetrd_buffer_size
zpotrf
Use the matching buffer-size helper to calculate the required workspace size.
zpotrf_batched
The S and D data types are real valued single and double precision, respectively.
zpotrf_buffer_size
zpotri
Use the matching buffer-size helper to calculate the required workspace size.
zpotri_buffer_size
zpotrs
Solves a system of linear equations
zpotrs_batched
Solves a sequence of linear systems
zsytrf
Use the matching buffer-size helper to calculate the required workspace size.
zsytrf_buffer_size
zungbr
zungbr_buffer_size
zungqr
zungqr_buffer_size
zungtr
zungtr_buffer_size
zunmqr
zunmqr_buffer_size
zunmtr
zunmtr_buffer_size