cpotrs

Function cpotrs 

pub fn cpotrs(
    ctx: &Context,
    fill_mode: FillMode,
    n: usize,
    nrhs: usize,
    a: &DeviceMemory<Complex32>,
    lda: usize,
    b: &mut DeviceMemory<Complex32>,
    ldb: usize,
    dev_info: &mut DeviceMemory<i32>,
) -> Result<()>
Solves a system of linear equations

where A is an $n \times n$ Hermitian matrix, only lower or upper part is meaningful. fill_mode indicates which part of the matrix is used. The other triangular part is left unchanged.

Call potrf first to factorize matrix A. If fill_mode is FillMode::Lower, A is lower triangular Cholesky factor L corresponding to $A = L\cdot L^H$. If fill_mode is FillMode::Upper, A is upper triangular Cholesky factor U corresponding to $A = U^{H}\cdot U$.

The operation is in-place, that is, matrix X overwrites matrix B with the same leading dimension ldb.

If the reported dev_info value is -i, the ith parameter is invalid.

Errors

Returns an error if cuSOLVER has not been initialized, if the matrix dimensions, right-hand-side count, or leading dimensions are invalid, if the current GPU architecture is unsupported, or if cuSOLVER reports an internal failure.