dgetrs

Function dgetrs 

pub fn dgetrs(
    ctx: &Context,
    operation: Operation,
    n: usize,
    nrhs: usize,
    a: &DeviceMemory<f64>,
    lda: usize,
    pivots: &DeviceMemory<i32>,
    b: &mut DeviceMemory<f64>,
    ldb: usize,
    dev_info: &mut DeviceMemory<i32>,
) -> Result<()>
Solves a linear system of multiple right-hand sides

where A is an $n \times n$ matrix, and was LU-factored by getrf, that is, lower triangular part of A is L, and upper triangular part (including diagonal elements) of A is U. B is an $n\times {nrhs}$ right-hand side matrix.

The operation argument is described by Operation.

pivots is returned by the matching getrf operation. It contains pivot indices, which are used to permute right-hand sides.

If the reported dev_info value is -i, the ith parameter is invalid.

Callers can combine getrf and getrs to complete a linear solver.

Errors

Returns an error if cuSOLVER has not been initialized, if the matrix dimensions or leading dimensions are invalid, if the current GPU architecture is unsupported, or if cuSOLVER reports an internal failure.