dorgqr

Function dorgqr 

pub fn dorgqr(
    ctx: &Context,
    m: usize,
    n: usize,
    k: usize,
    a: &mut DeviceMemory<f64>,
    lda: usize,
    tau: &DeviceMemory<f64>,
    workspace: &mut DeviceMemory<f64>,
    dev_info: &mut DeviceMemory<i32>,
) -> Result<()>
Use the matching buffer-size helper to calculate the required workspace size.

The S and D data types are real valued single and double precision, respectively.

The C and Z data types are complex valued single and double precision, respectively.

Generates the first n columns of the orthogonal matrix Q from the elementary reflectors returned by geqrf and stores them in A.

Provide workspace through workspace. Use the corresponding *_buffer_size helper to query the required workspace length. The workspace size in bytes is size_of::<T>() * lwork.

If the reported dev_info value is -i, the ith parameter is invalid.

Callers can combine geqrf and orgqr to complete orthogonalization.

Errors

Returns an error if cuSOLVER has not been initialized, if the matrix dimensions, reflector count, or leading dimension are invalid, if the current GPU architecture is unsupported, or if cuSOLVER reports an internal failure.