pub fn spotri(
ctx: &Context,
fill_mode: FillMode,
n: usize,
a: &mut DeviceMemory<f32>,
lda: usize,
workspace: &mut DeviceMemory<f32>,
dev_info: &mut DeviceMemory<i32>,
) -> Result<()>Expand description
Use the matching buffer-size helper to calculate the required workspace size.
The S and D data types are real valued single and double precision, respectively.
The C and Z data types are complex valued single and double precision, respectively.
Computes the inverse of a positive-definite matrix A using the Cholesky factorization
computed by potrf().
A is an $n \times n$ matrix containing the triangular factor L or U computed by the Cholesky factorization.
Only the lower or upper part is meaningful, as selected by fill_mode.
The other triangular part is left unchanged.
If fill_mode is FillMode::Lower, only the lower triangular part of A is processed and replaced by the lower triangular part of the inverse.
If fill_mode is FillMode::Upper, only the upper triangular part of A is processed and replaced by the upper triangular part of the inverse.
Provide workspace through workspace.
Use the corresponding *_buffer_size helper to query the required workspace length.
If the inverse computation fails because a leading minor of L or U is singular, dev_info indicates the smallest leading minor that is not positive definite.
If the reported dev_info value is -i, the ith parameter is invalid.
Errors
Returns an error if cuSOLVER has not been initialized, if the matrix dimensions or leading dimension are invalid, if the current GPU architecture is unsupported, or if cuSOLVER reports an internal failure.