Geqrf

Struct Geqrf 

pub struct Geqrf<TA, TTau = TA> { /* private fields */ }
Typed QR factorization operation.

Implementations

Source

impl<TA, TTau> Geqrf<TA, TTau>
where TA: DataTypeLike, TTau: DataTypeLike,

pub fn new(rows: usize, cols: usize) -> Self

Creates a typed GEQRF operation using the matrix data type as compute type.

pub const fn with_compute_type(self, compute_type: DataType) -> Self

Sets the compute type passed to the generic cuSOLVER X API.

pub const fn rows(&self) -> usize

Returns the matrix row count.

pub const fn cols(&self) -> usize

Returns the matrix column count.

pub const fn compute_type(&self) -> DataType

Returns the cuSOLVER compute type.

pub fn workspace_size( &self, ctx: &Context, params: &Params, a: MatrixRef<'_, TA>, tau: VectorRef<'_, TTau>, ) -> Result<WorkspaceSizes>

Returns the required device and host workspace sizes.

Errors

Returns an error if inputs are invalid or if cuSOLVER cannot report the workspace sizes.

pub fn run( &self, ctx: &Context, params: &Params, args: GeqrfArgs<'_, TA, TTau>, ) -> Result<()>

Computes the QR factorization in place.

Errors

Returns an error if inputs or workspaces are invalid, or if cuSOLVER reports a failure.