Larft

Struct Larft 

pub struct Larft<TV, TTau = TV, TT = TV> { /* private fields */ }
Typed LARFT triangular-factor operation.

Implementations

Source

impl<TV, TTau, TT> Larft<TV, TTau, TT>
where TV: DataTypeLike, TTau: DataTypeLike, TT: DataTypeLike,

pub fn new(direct: DirectMode, storev: StorevMode, n: usize, k: usize) -> Self

Creates a typed LARFT operation using T’s data type as compute type.

pub const fn with_compute_type(self, compute_type: DataType) -> Self

Sets the compute type passed to the generic cuSOLVER X API.

pub const fn direct(&self) -> DirectMode

Returns the reflector product direction.

pub const fn storev(&self) -> StorevMode

Returns the reflector storage mode.

pub const fn n(&self) -> usize

Returns the reflector order.

pub const fn k(&self) -> usize

Returns the number of elementary reflectors.

pub const fn compute_type(&self) -> DataType

Returns the cuSOLVER compute type.

pub fn workspace_size( &self, ctx: &Context, params: &Params, v: MatrixRef<'_, TV>, tau: VectorRef<'_, TTau>, t: MatrixRef<'_, TT>, ) -> Result<WorkspaceSizes>

Returns the required device and host workspace sizes.

Errors

Returns an error if inputs are invalid or if cuSOLVER cannot report the workspace sizes.

pub fn run( &self, ctx: &Context, params: &Params, args: LarftArgs<'_, TV, TTau, TT>, ) -> Result<()>

Forms the triangular factor in place.

Errors

Returns an error if inputs or workspaces are invalid, or if cuSOLVER reports a failure.