pub struct Potrf<T> { /* private fields */ }Expand description
Implementations
Sourceimpl<T> Potrf<T>where
T: DataTypeLike,
impl<T> Potrf<T>where
T: DataTypeLike,
Sourcepub fn new(fill_mode: FillMode, n: usize) -> Self
pub fn new(fill_mode: FillMode, n: usize) -> Self
Creates a typed POTRF operation using the matrix data type as compute type.
Sourcepub const fn with_compute_type(self, compute_type: DataType) -> Self
pub const fn with_compute_type(self, compute_type: DataType) -> Self
Sets the compute type passed to the generic cuSOLVER X API.
Sourcepub const fn compute_type(&self) -> DataType
pub const fn compute_type(&self) -> DataType
Returns the cuSOLVER compute type.
Sourcepub fn workspace_size(
&self,
ctx: &Context,
params: &Params,
a: MatrixRef<'_, T>,
) -> Result<WorkspaceSizes>
pub fn workspace_size( &self, ctx: &Context, params: &Params, a: MatrixRef<'_, T>, ) -> Result<WorkspaceSizes>
Returns the required device and host workspace sizes.
Errors
Returns an error if the matrix shape is invalid or cuSOLVER cannot report the workspace sizes.