Module irs

Module irs 

Structs

IrsInfos
IrsParams
IrsSolve
IrsSolveBindings
ResidualHistory
ResidualHistoryEntry

Functions

xgels
Provides the same solve as the typed cuSOLVER gels entry points, but through a generic Rust wrapper that exposes IRS configuration and reporting more directly. xgels allows additional control of the solver parameters such as setting:
xgels_buffer_size
xgesv
Provides the same solve as the typed cuSOLVER gesv entry points, but through a generic Rust wrapper that exposes IRS configuration and reporting more directly. xgesv allows additional control of the solver parameters such as setting:
xgesv_buffer_size