Module layout

Module layout 

Structs

BatchedMatrixRef
A reference to a batched matrix (pointer array) stored on the device.
BatchedVectorRef
A reference to a batched vector (pointer array) stored on the device.
ByteWorkspaceMut
A mutable reference to a byte workspace buffer on the device.
MatrixMut
A mutable reference to a matrix stored on the device.
MatrixRef
A reference to a matrix stored on the device.
SelectionWorkspaceSizes
StridedBatchedMatrixMut
A mutable reference to a strided batched matrix stored on the device.
StridedBatchedMatrixRef
A reference to a strided batched matrix stored on the device.
StridedBatchedVectorMut
A mutable reference to a strided batched vector stored on the device.
StridedBatchedVectorRef
A reference to a strided batched vector stored on the device.
VectorMut
A mutable reference to a vector stored on the device.
VectorRef
A reference to a vector stored on the device.
WorkspaceSizes