pub struct Params { /* private fields */ }Implementations
Sourceimpl Params
impl Params
Sourcepub fn set_adv_options(
&mut self,
function: Function,
algorithm: AlgorithmMode,
) -> Result<()>
pub fn set_adv_options( &mut self, function: Function, algorithm: AlgorithmMode, ) -> Result<()>
Configures the algorithm for a 64-bit cuSOLVER operation.
Errors
Returns an error if function and algorithm are not a valid
combination for cuSOLVER.
pub fn as_raw(&self) -> cusolverDnParams_t
Sourcepub unsafe fn from_raw(handle: cusolverDnParams_t) -> Result<Self>
pub unsafe fn from_raw(handle: cusolverDnParams_t) -> Result<Self>
Takes ownership of a raw cuSOLVER params handle.
Safety
handle must be a valid cusolverDnParams_t created by cuSOLVER. The
returned wrapper takes ownership and will destroy it with
cusolverDnDestroyParams; no other owner may destroy or keep using it.
Sourcepub fn into_raw(self) -> cusolverDnParams_t
pub fn into_raw(self) -> cusolverDnParams_t
Releases ownership and returns the raw cuSOLVER params handle.
The caller becomes responsible for destroying the handle.