Module types

Module types 

Enums

AlgorithmMode
Algorithm selected by Params::set_adv_options. The set of algorithms supported for each operation is described with that operation’s documentation.
DeterministicMode
Indicates whether repeated cuSOLVER executions with the same input are required to produce bitwise-identical results.
DiagonalType
DirectMode
Specifies the order in which the elementary reflectors are multiplied to form the block reflector.
EigenMode
Selects whether to compute eigenvectors.
EigenRange
EigenType
Selects the generalized eigenvalue problem type.
FillMode
Selects which filled part of a dense matrix is used by the operation.
Function
Indicates which operation is configured by Params::set_adv_options. Function::Getrf corresponds to the getrf operation.
IrsRefinement
Indicates which IRS refinement solver to use for a cuSOLVER operation. Empirically, IrsRefinement::Gmres is often the best option.
MathMode
Compute precision mode selected by set_math_mode.
Norm
Operation
Selects the operation to perform with a dense matrix.
PrecisionType
SideMode
StorevMode
Specifies how the vectors which define the elementary reflectors are stored.
SvdMode
TruncatedSvdMode