Module dense

Module dense 

Dense cuSOLVER operation wrappers.

Public APIs should prefer typed operation families such as Potrf, Getrf, and Geqrf. Upstream S/D/C/Z entry-point wrappers are implementation details unless an operation has not yet been lifted into a typed family.

Modules

legacy

Structs

BatchedPotrf
Typed batched Cholesky factorization operation.
BatchedPotrfArgs
Runtime buffers for BatchedPotrf::run.
BatchedPotrs
Typed batched Cholesky solve operation.
BatchedPotrsArgs
Runtime buffers for BatchedPotrs::run.
Gebrd
Typed bidiagonal reduction operation.
GebrdArgs
Runtime buffers for Gebrd::run.
Geqrf
Typed QR factorization operation.
GeqrfArgs
Runtime buffers for Geqrf::run.
Getrf
Typed LU factorization operation.
GetrfArgs
Runtime buffers for Getrf::run.
Getrs
Typed LU solve operation.
GetrsArgs
Runtime buffers for Getrs::run.
Larft
Typed LARFT triangular-factor operation.
LarftArgs
Runtime buffers for Larft::run.
Orgbr
Typed operation that forms explicit bidiagonalization factors.
OrgbrArgs
Runtime buffers for Orgbr::run.
Orgqr
Typed operation that forms explicit QR factors.
OrgqrArgs
Runtime buffers for Orgqr::run.
Orgtr
Typed operation that forms explicit tridiagonalization factors.
OrgtrArgs
Runtime buffers for Orgtr::run.
Ormqr
Typed operation that applies QR reflectors to a matrix.
OrmqrArgs
Runtime buffers for Ormqr::run.
Ormtr
Typed operation that applies tridiagonalization factors to a matrix.
OrmtrArgs
Runtime buffers for Ormtr::run.
Potrf
Typed Cholesky factorization operation.
PotrfArgs
Runtime buffers for Potrf::run.
Potri
Typed Cholesky inverse operation.
PotriArgs
Runtime buffers for Potri::run.
Potrs
Typed Cholesky solve operation.
PotrsArgs
Runtime buffers for Potrs::run.
Sytrd
Typed symmetric or Hermitian tridiagonal reduction operation.
SytrdArgs
Runtime buffers for Sytrd::run.
Sytrf
Typed symmetric or Hermitian indefinite factorization operation.
SytrfArgs
Runtime buffers for Sytrf::run.
Sytrs
Typed symmetric or Hermitian solve operation.
SytrsArgs
Runtime buffers for Sytrs::run.
Trtri
Typed triangular inverse operation.
TrtriArgs
Runtime buffers for Trtri::run.

Traits

GebrdScalar
OrgbrScalar
OrgqrScalar
OrgtrScalar
OrmqrScalar
OrmtrScalar
PotrfBatchedScalar
PotriScalar
PotrsBatchedScalar
SytrdScalar
SytrfScalar

Functions

xgetrf
Computes the LU factorization of an $m \times n$ matrix
xgetrf_buffer_size
xgetrs
Solves a linear system of multiple right-hand sides
xlarft
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xlarft_buffer_size
xpotrf
Use xpotrf_buffer_size to calculate the sizes needed for pre-allocated workspace.
xpotrf_buffer_size
xpotrs
Solves a system of linear equations.
xsytrs
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xsytrs_buffer_size
xtrtri
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
xtrtri_buffer_size