Functions
- cgebrd
- Use the matching buffer-size helper to calculate the required workspace size.
- cgebrd_
buffer_ size - cgeqrf
- Use the matching buffer-size helper to calculate the required workspace size.
- cgeqrf_
buffer_ size - cgetrf
- Use the matching buffer-size helper to calculate the required workspace size.
- cgetrf_
buffer_ size - cgetrs
- Solves a linear system of multiple right-hand sides
- chetrd
- chetrd_
buffer_ size - cpotrf
- Use the matching buffer-size helper to calculate the required workspace size.
- cpotrf_
batched - The S and D data types are real valued single and double precision, respectively.
- cpotrf_
buffer_ size - cpotri
- Use the matching buffer-size helper to calculate the required workspace size.
- cpotri_
buffer_ size - cpotrs
- Solves a system of linear equations
- csytrf
- Use the matching buffer-size helper to calculate the required workspace size.
- csytrf_
buffer_ size - cungbr
- cungbr_
buffer_ size - cungqr
- cungqr_
buffer_ size - cungtr
- cungtr_
buffer_ size - cunmqr
- cunmqr_
buffer_ size - cunmtr
- cunmtr_
buffer_ size - dgebrd
- Use the matching buffer-size helper to calculate the required workspace size.
- dgebrd_
buffer_ size - dgeqrf
- Use the matching buffer-size helper to calculate the required workspace size.
- dgeqrf_
buffer_ size - dgetrf
- Use the matching buffer-size helper to calculate the required workspace size.
- dgetrf_
buffer_ size - dgetrs
- Solves a linear system of multiple right-hand sides
- dorgbr
- Use the matching buffer-size helper to calculate the required workspace size.
- dorgbr_
buffer_ size - dorgqr
- Use the matching buffer-size helper to calculate the required workspace size.
- dorgqr_
buffer_ size - dorgtr
- Use the matching buffer-size helper to calculate the required workspace size.
- dorgtr_
buffer_ size - dormqr
- Use the matching buffer-size helper to calculate the required workspace size.
- dormqr_
buffer_ size - dormtr
- Use the matching buffer-size helper to calculate the required workspace size.
- dormtr_
buffer_ size - dpotrf
- Use the matching buffer-size helper to calculate the required workspace size.
- dpotrf_
batched - The S and D data types are real valued single and double precision, respectively.
- dpotrf_
buffer_ size - dpotri
- Use the matching buffer-size helper to calculate the required workspace size.
- dpotri_
buffer_ size - dpotrs
- Solves a system of linear equations
- dpotrs_
batched - Solves a sequence of linear systems
- dsytrd
- Use the matching buffer-size helper to calculate the required workspace size.
- dsytrd_
buffer_ size - dsytrf
- Use the matching buffer-size helper to calculate the required workspace size.
- dsytrf_
buffer_ size - sgebrd
- Use the matching buffer-size helper to calculate the required workspace size.
- sgebrd_
buffer_ size - sgeqrf
- Use the matching buffer-size helper to calculate the required workspace size.
- sgeqrf_
buffer_ size - sgetrf
- Use the matching buffer-size helper to calculate the required workspace size.
- sgetrf_
buffer_ size - sgetrs
- Solves a linear system of multiple right-hand sides
- sorgbr
- Use the matching buffer-size helper to calculate the required workspace size.
- sorgbr_
buffer_ size - sorgqr
- Use the matching buffer-size helper to calculate the required workspace size.
- sorgqr_
buffer_ size - sorgtr
- Use the matching buffer-size helper to calculate the required workspace size.
- sorgtr_
buffer_ size - sormqr
- Use the matching buffer-size helper to calculate the required workspace size.
- sormqr_
buffer_ size - sormtr
- Use the matching buffer-size helper to calculate the required workspace size.
- sormtr_
buffer_ size - spotrf
- Use the matching buffer-size helper to calculate the required workspace size.
- spotrf_
batched - The S and D data types are real valued single and double precision, respectively.
- spotrf_
buffer_ size - spotri
- Use the matching buffer-size helper to calculate the required workspace size.
- spotri_
buffer_ size - spotrs
- Solves a system of linear equations
- spotrs_
batched - Solves a sequence of linear systems
- ssytrd
- Use the matching buffer-size helper to calculate the required workspace size.
- ssytrd_
buffer_ size - ssytrf
- Use the matching buffer-size helper to calculate the required workspace size.
- ssytrf_
buffer_ size - xgeqrf
- Use
xgeqrf_buffer_sizeto calculate the sizes needed for pre-allocated workspace. - xgeqrf_
buffer_ size - xgetrf
- Computes the LU factorization of an $m \times n$ matrix
- xgetrf_
buffer_ size - xgetrs
- Solves a linear system of multiple right-hand sides
- xlarft
- Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
- xlarft_
buffer_ size - xpotrf
- Use
xpotrf_buffer_sizeto calculate the sizes needed for pre-allocated workspace. - xpotrf_
buffer_ size - xpotrs
- Solves a system of linear equations.
- xsytrs
- Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
- xsytrs_
buffer_ size - xtrtri
- Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
- xtrtri_
buffer_ size - zgebrd
- Use the matching buffer-size helper to calculate the required workspace size.
- zgebrd_
buffer_ size - zgeqrf
- Use the matching buffer-size helper to calculate the required workspace size.
- zgeqrf_
buffer_ size - zgetrf
- Use the matching buffer-size helper to calculate the required workspace size.
- zgetrf_
buffer_ size - zgetrs
- Solves a linear system of multiple right-hand sides
- zhetrd
- zhetrd_
buffer_ size - zpotrf
- Use the matching buffer-size helper to calculate the required workspace size.
- zpotrf_
batched - The S and D data types are real valued single and double precision, respectively.
- zpotrf_
buffer_ size - zpotri
- Use the matching buffer-size helper to calculate the required workspace size.
- zpotri_
buffer_ size - zpotrs
- Solves a system of linear equations
- zpotrs_
batched - Solves a sequence of linear systems
- zsytrf
- Use the matching buffer-size helper to calculate the required workspace size.
- zsytrf_
buffer_ size - zungbr
- zungbr_
buffer_ size - zungqr
- zungqr_
buffer_ size - zungtr
- zungtr_
buffer_ size - zunmqr
- zunmqr_
buffer_ size - zunmtr
- zunmtr_
buffer_ size