pub struct Geqrf<TA, TTau = TA> { /* private fields */ }Expand description
Typed QR factorization operation.
Implementations
Sourceimpl<TA, TTau> Geqrf<TA, TTau>where
TA: DataTypeLike,
TTau: DataTypeLike,
impl<TA, TTau> Geqrf<TA, TTau>where
TA: DataTypeLike,
TTau: DataTypeLike,
Sourcepub fn new(rows: usize, cols: usize) -> Self
pub fn new(rows: usize, cols: usize) -> Self
Creates a typed GEQRF operation using the matrix data type as compute type.
Sourcepub const fn with_compute_type(self, compute_type: DataType) -> Self
pub const fn with_compute_type(self, compute_type: DataType) -> Self
Sets the compute type passed to the generic cuSOLVER X API.
Sourcepub const fn compute_type(&self) -> DataType
pub const fn compute_type(&self) -> DataType
Returns the cuSOLVER compute type.
Sourcepub fn workspace_size(
&self,
ctx: &Context,
params: &Params,
a: MatrixRef<'_, TA>,
tau: VectorRef<'_, TTau>,
) -> Result<WorkspaceSizes>
pub fn workspace_size( &self, ctx: &Context, params: &Params, a: MatrixRef<'_, TA>, tau: VectorRef<'_, TTau>, ) -> Result<WorkspaceSizes>
Returns the required device and host workspace sizes.
Errors
Returns an error if inputs are invalid or if cuSOLVER cannot report the workspace sizes.