pub struct Larft<TV, TTau = TV, TT = TV> { /* private fields */ }Expand description
Typed LARFT triangular-factor operation.
Implementations
Sourceimpl<TV, TTau, TT> Larft<TV, TTau, TT>
impl<TV, TTau, TT> Larft<TV, TTau, TT>
Sourcepub fn new(direct: DirectMode, storev: StorevMode, n: usize, k: usize) -> Self
pub fn new(direct: DirectMode, storev: StorevMode, n: usize, k: usize) -> Self
Creates a typed LARFT operation using T’s data type as compute type.
Sourcepub const fn with_compute_type(self, compute_type: DataType) -> Self
pub const fn with_compute_type(self, compute_type: DataType) -> Self
Sets the compute type passed to the generic cuSOLVER X API.
Sourcepub const fn direct(&self) -> DirectMode
pub const fn direct(&self) -> DirectMode
Returns the reflector product direction.
Sourcepub const fn storev(&self) -> StorevMode
pub const fn storev(&self) -> StorevMode
Returns the reflector storage mode.
Sourcepub const fn compute_type(&self) -> DataType
pub const fn compute_type(&self) -> DataType
Returns the cuSOLVER compute type.
Sourcepub fn workspace_size(
&self,
ctx: &Context,
params: &Params,
v: MatrixRef<'_, TV>,
tau: VectorRef<'_, TTau>,
t: MatrixRef<'_, TT>,
) -> Result<WorkspaceSizes>
pub fn workspace_size( &self, ctx: &Context, params: &Params, v: MatrixRef<'_, TV>, tau: VectorRef<'_, TTau>, t: MatrixRef<'_, TT>, ) -> Result<WorkspaceSizes>
Returns the required device and host workspace sizes.
Errors
Returns an error if inputs are invalid or if cuSOLVER cannot report the workspace sizes.