pub struct Ormtr<T> { /* private fields */ }Expand description
Typed operation that applies tridiagonalization factors to a matrix.
Implementations
Sourceimpl<T> Ormtr<T>where
T: OrmtrScalar,
impl<T> Ormtr<T>where
T: OrmtrScalar,
Sourcepub const fn new(
side: SideMode,
fill_mode: FillMode,
operation: Operation,
rows: usize,
cols: usize,
) -> Self
pub const fn new( side: SideMode, fill_mode: FillMode, operation: Operation, rows: usize, cols: usize, ) -> Self
Creates a typed ORMTR/UNMTR operation.
Sourcepub const fn side(&self) -> SideMode
pub const fn side(&self) -> SideMode
Returns which side receives the tridiagonalization factor product.
Sourcepub const fn operation(&self) -> Operation
pub const fn operation(&self) -> Operation
Returns the operation applied to the factor product.
Sourcepub fn workspace_len(
&self,
ctx: &Context,
reflectors: MatrixRef<'_, T>,
tau: VectorRef<'_, T>,
matrix: MatrixRef<'_, T>,
) -> Result<usize>
pub fn workspace_len( &self, ctx: &Context, reflectors: MatrixRef<'_, T>, tau: VectorRef<'_, T>, matrix: MatrixRef<'_, T>, ) -> Result<usize>
Returns the required legacy workspace length in elements.
Errors
Returns an error if inputs are invalid or if cuSOLVER cannot report the workspace length.