Module eigen

Module eigen 

Structs

Syevd
SyevdBindings
SyevdInput
Syevdx
SyevjInfo

Enums

EigenSelection

Functions

cheevd
cheevd_buffer_size
cheevdx
cheevdx_buffer_size
cheevj
cheevj_batched
cheevj_batched_buffer_size
cheevj_buffer_size
chegvd
chegvd_buffer_size
chegvdx_selected
chegvdx_selected_buffer_size
chegvj
chegvj_buffer_size
dsyevd
Use the matching buffer-size helper to calculate the workspace length before allocating workspace.
dsyevd_buffer_size
dsyevdx
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsyevdx_buffer_size
dsyevj
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsyevj_batched
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsyevj_batched_buffer_size
dsyevj_buffer_size
dsygvd
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsygvd_buffer_size
dsygvdx_selected
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsygvdx_selected_buffer_size
dsygvj
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
dsygvj_buffer_size
ssyevd
Use the matching buffer-size helper to calculate the workspace length before allocating workspace.
ssyevd_buffer_size
ssyevdx
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
ssyevdx_buffer_size
ssyevj
Use the matching buffer-size helper to calculate the workspace length before allocating workspace.
ssyevj_batched
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
ssyevj_batched_buffer_size
ssyevj_buffer_size
ssygvd
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
ssygvd_buffer_size
ssygvdx_selected
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
ssygvdx_selected_buffer_size
ssygvj
Use the matching buffer-size helper to calculate the sizes needed for pre-allocated workspace.
ssygvj_buffer_size
xgeev
Computes the eigenvalues and, optionally, the left and/or right eigenvectors of an n-by-n real non-symmetric or complex non-Hermitian matrix A. The right eigenvector v(j) of A satisfies
xgeev_buffer_size
xsyev_batched
Computes eigenvalues and eigenvectors of a sequence of symmetric (Hermitian) $n \times n$ matrices.
xsyev_batched_buffer_size
xsyevd
xsyevd_buffer_size
xsyevdx
xsyevdx_buffer_size
zheevd
zheevd_buffer_size
zheevdx
zheevdx_buffer_size
zheevj
zheevj_batched
zheevj_batched_buffer_size
zheevj_buffer_size
zhegvd
zhegvd_buffer_size
zhegvdx_selected
zhegvdx_selected_buffer_size
zhegvj
zhegvj_buffer_size