pub struct SyevjInfo { /* private fields */ }Implementations
Sourceimpl SyevjInfo
impl SyevjInfo
Sourcepub fn set_tolerance(&mut self, tolerance: f64) -> Result<()>
pub fn set_tolerance(&mut self, tolerance: f64) -> Result<()>
Sourcepub fn set_max_sweeps(&mut self, max_sweeps: i32) -> Result<()>
pub fn set_max_sweeps(&mut self, max_sweeps: i32) -> Result<()>
Configures the maximum number of syevj sweeps.
The default value is 100.
Errors
Returns an error if cuSOLVER rejects the sweep count.
Sourcepub fn set_sort_eigenvalues(&mut self, sort_eigenvalues: bool) -> Result<()>
pub fn set_sort_eigenvalues(&mut self, sort_eigenvalues: bool) -> Result<()>
If sort_eigenvalues is false, the eigenvalues are not sorted.
This setting only applies to syevj_batched.
syevj and sygvj always sort eigenvalues in ascending order.
By default, eigenvalues are always sorted in ascending order.
Errors
Returns an error if cuSOLVER rejects the sort setting.
Sourcepub fn residual(&self, ctx: &Context) -> Result<f64>
pub fn residual(&self, ctx: &Context) -> Result<f64>
Returns the residual reported by syevj or sygvj.
This accessor does not support syevj_batched.
Calling this after syevj_batched returns Status::NotSupported.
Errors
Returns an error if the info handle was used with syevj_batched,
which does not report a residual.
Sourcepub fn executed_sweeps(&self, ctx: &Context) -> Result<i32>
pub fn executed_sweeps(&self, ctx: &Context) -> Result<i32>
Returns the number of executed syevj or sygvj sweeps.
This accessor does not support syevj_batched.
Calling this after syevj_batched returns Status::NotSupported.
Errors
Returns an error if the info handle was used with syevj_batched,
which does not report a sweep count.