Status

Enum Status 

#[non_exhaustive]
pub enum Status {
Show 26 variants Success, NotInitialized, AllocFailed, InvalidValue, ArchitectureMismatch, MappingError, ExecutionFailed, InternalError, MatrixTypeNotSupported, NotSupported, ZeroPivot, InvalidLicense, IrsParamsNotInitialized, IrsParamsInvalid, IrsParamsInvalidPrec, IrsParamsInvalidRefine, IrsParamsInvalidMaxIter, IrsInternalError, IrsNotSupported, IrsOutOfRange, IrsNrhsNotSupportedForRefineGmres, IrsInfosNotInitialized, IrsInfosNotDestroyed, IrsMatrixSingular, InvalidWorkspace, Unknown(u32),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Success

The operation completed successfully.



NotInitialized

The cuSOLVER library was not initialized.



AllocFailed

Resource allocation failed.



InvalidValue

An invalid value was provided.



ArchitectureMismatch

The current device architecture is not supported.



MappingError

Memory or resource mapping failed.



ExecutionFailed

Kernel execution failed.



InternalError

An internal cuSOLVER error occurred.



MatrixTypeNotSupported

The matrix type is not supported by the operation.



NotSupported

The requested operation is not supported.



ZeroPivot

A zero pivot was encountered.



InvalidLicense

The cuSOLVER license is invalid.



IrsParamsNotInitialized

IRS parameters were not initialized.



IrsParamsInvalid

IRS parameters are invalid.



IrsParamsInvalidPrec

IRS precision parameters are invalid.



IrsParamsInvalidRefine

IRS refinement parameters are invalid.



IrsParamsInvalidMaxIter

IRS max-iteration parameters are invalid.



IrsInternalError

An internal IRS error occurred.



IrsNotSupported

The requested IRS configuration is not supported.



IrsOutOfRange

IRS configuration values are out of range.



IrsNrhsNotSupportedForRefineGmres

GMRES refinement does not support the requested number of right-hand sides.



IrsInfosNotInitialized

IRS info structures were not initialized.



IrsInfosNotDestroyed

IRS info structures were not destroyed before reuse.



IrsMatrixSingular

The IRS system matrix is singular.



InvalidWorkspace

The provided workspace is invalid.



Unknown(u32)

A status code not known to this version of Singe.

Implementations

Source

impl Status

pub const fn description(self) -> &'static str

pub const fn raw(self) -> u32