Structs
Functions
- xgels
- Provides the same solve as the typed cuSOLVER
gelsentry points, but through a generic Rust wrapper that exposes IRS configuration and reporting more directly.xgelsallows additional control of the solver parameters such as setting: - xgels_
buffer_ size - xgesv
- Provides the same solve as the typed cuSOLVER
gesventry points, but through a generic Rust wrapper that exposes IRS configuration and reporting more directly.xgesvallows additional control of the solver parameters such as setting: - xgesv_
buffer_ size