Structs
- Batched
Matrix Ref - A reference to a batched matrix (pointer array) stored on the device.
- Batched
Vector Ref - A reference to a batched vector (pointer array) stored on the device.
- Byte
Workspace Mut - A mutable reference to a byte workspace buffer on the device.
- Matrix
Mut - A mutable reference to a matrix stored on the device.
- Matrix
Ref - A reference to a matrix stored on the device.
- Selection
Workspace Sizes - Strided
Batched Matrix Mut - A mutable reference to a strided batched matrix stored on the device.
- Strided
Batched Matrix Ref - A reference to a strided batched matrix stored on the device.
- Strided
Batched Vector Mut - A mutable reference to a strided batched vector stored on the device.
- Strided
Batched Vector Ref - A reference to a strided batched vector stored on the device.
- Vector
Mut - A mutable reference to a vector stored on the device.
- Vector
Ref - A reference to a vector stored on the device.
- Workspace
Sizes