Params

Struct Params 

pub struct Params { /* private fields */ }

Implementations

Source

impl Params

pub fn create() -> Result<Self>

Creates and initializes the parameter structure for the cuSOLVER 64-bit interface.

The returned Params owns the cuSOLVER parameter handle and destroys it when dropped.

Errors

Returns an error if cuSOLVER cannot allocate the parameter structure or if it does not return a valid handle.

pub fn set_adv_options( &mut self, function: Function, algorithm: AlgorithmMode, ) -> Result<()>

Configures the algorithm for a 64-bit cuSOLVER operation.

Errors

Returns an error if function and algorithm are not a valid combination for cuSOLVER.

pub fn as_raw(&self) -> cusolverDnParams_t