Enums
- Algorithm
Mode - Algorithm selected by
Params::set_adv_options. The set of algorithms supported for each operation is described with that operation’s documentation. - Deterministic
Mode - Indicates whether repeated cuSOLVER executions with the same input are required to produce bitwise-identical results.
- Diagonal
Type - Direct
Mode - Specifies the order in which the elementary reflectors are multiplied to form the block reflector.
- Eigen
Mode - Selects whether to compute eigenvectors.
- Eigen
Range - Eigen
Type - Selects the generalized eigenvalue problem type.
- Fill
Mode - Selects which filled part of a dense matrix is used by the operation.
- Function
- Indicates which operation is configured by
Params::set_adv_options.Function::Getrfcorresponds to thegetrfoperation. - IrsRefinement
- Indicates which IRS refinement solver to use for a cuSOLVER operation.
Empirically,
IrsRefinement::Gmresis often the best option. - Math
Mode - Compute precision mode selected by
set_math_mode. - Norm
- Operation
- Selects the operation to perform with a dense matrix.
- Precision
Type - Side
Mode - Storev
Mode - Specifies how the vectors which define the elementary reflectors are stored.
- SvdMode
- Truncated
SvdMode